@@ -41,7 +41,7 @@ ChangeSvyTable <- function(svy, ori){
       res$CatTable[[i]][[j]][,'freq'] <- ori$CatTable[[i]][[j]][,'freq']
     }
   }
-
+  
   if(length(cont_var)==0){
     for (i in seq_along(res$CatTable)){
       res$CatTable[[i]][[1]][ , 'n'] <- ori$CatTable[[i]][[1]][ , 'n']
@@ -107,20 +107,20 @@ svyCreateTableOne2 <- function(data, strata, vars, factorVars, includeNA = F, te
                                catDigits = 1, contDigits = 2, pDigits = 3, Labels = F, labeldata = NULL, minMax = F, showpm = T,
                                addOverall = F, pairwise = F, pairwise.showtest = F, n_original = T) {
   setkey <- variable <- level <- . <- val_label <- NULL
-
+  
   if (length(strata) != 1) {
     stop("Please select only 1 strata")
   }
-
+  
   vars.ex <- names(which(sapply(vars, function(x) {
     !(class(data$variables[[x]]) %in% c("integer", "numeric", "factor", "character"))
   })))
-
+  
   if (length(vars.ex) > 0) {
     warning("Variables other than numeric or factor types are excluded.")
     vars <- setdiff(vars, vars.ex)
   }
-
+  
   res2 <- tableone::svyCreateTableOne(
     vars = vars, strata = strata, data = data, factorVars = factorVars, includeNA = includeNA, test = test,
     smd = smd, addOverall = addOverall
@@ -135,7 +135,7 @@ svyCreateTableOne2 <- function(data, strata, vars, factorVars, includeNA = F, te
     res <- res2
   }
   factor_vars <- res2[["MetaData"]][["varFactors"]]
-
+  
   if (Labels & !is.null(labeldata)) {
     labelled::var_label(data$variables) <- sapply(names(data$variables), function(v) {
       as.character(labeldata[get("variable") == v, "var_label"][1])
@@ -153,33 +153,33 @@ svyCreateTableOne2 <- function(data, strata, vars, factorVars, includeNA = F, te
       }
     }
     ptb1.res0 <- print(res0,
-      showAllLevels = showAllLevels, printToggle = printToggle, quote = quote, varLabels = Labels, nonnormal = nonnormal,
-      catDigits = catDigits, contDigits = contDigits, minMax = minMax, addOverall = addOverall
+                       showAllLevels = showAllLevels, printToggle = printToggle, quote = quote, varLabels = Labels, nonnormal = nonnormal,
+                       catDigits = catDigits, contDigits = contDigits, minMax = minMax, addOverall = addOverall
     )
     ptb1.rn <- rownames(ptb1.res0)
     ptb1.rn <- gsub("(mean (SD))", "", ptb1.rn, fixed = T)
   }
-
+  
   #문제
   ptb1 <- print(res,
-   showAllLevels = showAllLevels, printToggle = printToggle, quote = quote, smd = smd, varLabels = Labels, nonnormal = nonnormal,
-   catDigits = catDigits, contDigits = contDigits, pDigits = pDigits, minMax = minMax
+                showAllLevels = showAllLevels, printToggle = printToggle, quote = quote, smd = smd, varLabels = Labels, nonnormal = nonnormal,
+                catDigits = catDigits, contDigits = contDigits, pDigits = pDigits, minMax = minMax
   )
-
+  
   
   
   if (showpm) {
     ptb1[grepl("\\(mean \\(SD\\)\\)", rownames(ptb1)), ] <- gsub("\\(", "\u00B1 ", ptb1[grepl("\\(mean \\(SD\\)\\)", rownames(ptb1)), ])
     ptb1[grepl("\\(mean \\(SD\\)\\)", rownames(ptb1)), ] <- gsub("\\)", "", ptb1[grepl("\\(mean \\(SD\\)\\)", rownames(ptb1)), ])
   }
-
+  
   rownames(ptb1) <- gsub("(mean (SD))", "", rownames(ptb1), fixed = T)
   if (Labels & !is.null(labeldata)) {
     rownames(ptb1) <- ptb1.rn
     if (showAllLevels == T) ptb1[, 1] <- ptb1.res0[, 1]
   }
   # cap.tb1 = paste("Table 1: Stratified by ", strata, sep="")
-
+  
   if (Labels & !is.null(labeldata)) {
     colname.group_var <- unlist(labeldata[get("variable") == strata & get("level") %in% unique(data$variables[[strata]]), "val_label"])
     if (length(colname.group_var) == 0 & addOverall) {
@@ -192,7 +192,7 @@ svyCreateTableOne2 <- function(data, strata, vars, factorVars, includeNA = F, te
       colnames(ptb1)[1:length(colname.group_var)] <- colname.group_var
     }
   }
-
+  
   if (pairwise && length(unique(data$variables[[strata]])) > 2) {
     unique_strata <- sort(unique(stats::na.omit(data$variables[[strata]])))
     pairwise_comparisons <- combn(unique_strata, 2, simplify = FALSE)
@@ -255,7 +255,7 @@ svyCreateTableOne2 <- function(data, strata, vars, factorVars, includeNA = F, te
     if (!is.null(labeldata) && Labels) {
       pairwise_p_cols <- grep("^p\\(", colnames(ptb1), value = TRUE)
       pairwise_test_cols <- grep("^test\\(", colnames(ptb1), value = TRUE)
-
+      
       strata_labels <- stats::setNames(labeldata[labeldata$variable == strata, val_label], labeldata[labeldata$variable == strata, level])
       updated_p_colnames <- sapply(pairwise_p_cols, function(col_name) {
         match <- regmatches(col_name, regexec("^p\\(([^vs]+)vs([^\\)]+)\\)", col_name))
@@ -283,7 +283,7 @@ svyCreateTableOne2 <- function(data, strata, vars, factorVars, includeNA = F, te
         }
         return(col_name)
       })
-
+      
       colnames(ptb1)[colnames(ptb1) %in% pairwise_p_cols] <- updated_p_colnames
       colnames(ptb1)[colnames(ptb1) %in% pairwise_test_cols] <- updated_test_colnames
     }
@@ -353,15 +353,15 @@ svyCreateTableOneJS <- function(vars, strata = NULL, strata2 = NULL, data, facto
                                 catDigits = 1, contDigits = 2, pDigits = 3, labeldata = NULL, psub = T, minMax = F, showpm = T,
                                 addOverall = F, pairwise = F, pairwise.showtest = F, n_original = T) {
   . <- level <- variable <- val_label <- V1 <- V2 <- NULL
-
+  
   # if (Labels & !is.null(labeldata)){
   #  var_label(data) = sapply(names(data), function(v){as.character(labeldata[get("variable") == v, "var_label"][1])}, simplify = F)
   #  vals.tb1 = c(NA, unlist(sapply(vars, function(v){labeldata[get("variable") == v, "val_label"]})))
   # }
   data <- data
-
-  if (is.null(strata)) {
   
+  if (is.null(strata)) {
+    
     if (Labels & !is.null(labeldata)) {
       labelled::var_label(data$variables) <- sapply(names(data$variables), function(v) {
         as.character(labeldata[get("variable") == v, "var_label"][1])
@@ -388,19 +388,19 @@ svyCreateTableOneJS <- function(vars, strata = NULL, strata2 = NULL, data, facto
         }
       }
     }
-
+    
     ptb1 <- print(res,
-      showAllLevels = showAllLevels, printToggle = printToggle, quote = quote, varLabels = Labels, nonnormal = nonnormal,
-      catDigits = catDigits, contDigits = contDigits, minMax = minMax
+                  showAllLevels = showAllLevels, printToggle = printToggle, quote = quote, varLabels = Labels, nonnormal = nonnormal,
+                  catDigits = catDigits, contDigits = contDigits, minMax = minMax
     )
-
+    
     if (showpm) {
       ptb1[grepl("\\(mean \\(SD\\)\\)", rownames(ptb1)), ] <- gsub("\\(", "\u00B1 ", ptb1[grepl("\\(mean \\(SD\\)\\)", rownames(ptb1)), ])
       ptb1[grepl("\\(mean \\(SD\\)\\)", rownames(ptb1)), ] <- gsub("\\)", "", ptb1[grepl("\\(mean \\(SD\\)\\)", rownames(ptb1)), ])
     }
-
+    
     rownames(ptb1) <- gsub("(mean (SD))", "", rownames(ptb1), fixed = T)
-
+    
     cap.tb1 <- "Total - weighted data"
     # if (Labels & !is.null(labeldata)){
     #  ptb1[,1] <- vals.tb1
@@ -423,9 +423,9 @@ svyCreateTableOneJS <- function(vars, strata = NULL, strata2 = NULL, data, facto
       )
     }
     
-
+    
     cap.tb1 <- paste("Stratified by ", strata, "- weighted data", sep = "")
-
+    
     if (Labels & !is.null(labeldata)) {
       cap.tb1 <- paste("Stratified by ", labeldata[get("variable") == strata, "var_label"][1], "- weighted data", sep = "")
       # ptb1[,1] = vals.tb1
@@ -435,22 +435,36 @@ svyCreateTableOneJS <- function(vars, strata = NULL, strata2 = NULL, data, facto
     data.strata <- lapply(setdiff(unique(data$variable[[strata]]), NA), function(x) {
       subset(data, get(strata) == x)
     })
-
+    
     if(n_original){
       ptb1.list <- lapply(data.strata, svyCreateTableOne2,
                           vars = vars, strata = strata2, factorVars = factorVars, includeNA = includeNA, test = test, smd = smd,
-                          showAllLevels = showAllLevels, printToggle = printToggle, quote = quote, Labels = F, nonnormal = nonnormal,
-                          catDigits = catDigits, contDigits = contDigits, pDigits = pDigits, minMax = minMax, showpm = showpm, addOverall = F, n_original = T
+                          showAllLevels = showAllLevels, printToggle = printToggle, quote = quote, Labels = Labels, nonnormal = nonnormal,
+                          catDigits = catDigits, contDigits = contDigits, pDigits = pDigits, minMax = minMax, showpm = showpm, addOverall = F, n_original = T, labeldata = labeldata
       )
     }else{
       ptb1.list <- lapply(data.strata, svyCreateTableOne2,
                           vars = vars, strata = strata2, factorVars = factorVars, includeNA = includeNA, test = test, smd = smd,
-                          showAllLevels = showAllLevels, printToggle = printToggle, quote = quote, Labels = F, nonnormal = nonnormal,
-                          catDigits = catDigits, contDigits = contDigits, pDigits = pDigits, minMax = minMax, showpm = showpm, addOverall = F, n_original = F
+                          showAllLevels = showAllLevels, printToggle = printToggle, quote = quote, Labels = Labels, nonnormal = nonnormal,
+                          catDigits = catDigits, contDigits = contDigits, pDigits = pDigits, minMax = minMax, showpm = showpm, addOverall = F, n_original = F, labeldata = labeldata
       )
     }
     
-
+    
+    if (Labels & !is.null(labeldata)) {
+      data.table::setkey(labeldata, variable, level)
+      strata_labels <- labeldata[.(strata, names(data.strata)), val_label]
+      strata2_labels <- unique(labeldata[variable == strata2, val_label])
+      
+      ptb1.list <- mapply(function(tbl, strata_label) {
+        cols_to_rename <- intersect(colnames(tbl), strata2_labels)
+        if (length(cols_to_rename) > 0) {
+          colnames(tbl)[colnames(tbl) %in% cols_to_rename] <- paste(strata_label, cols_to_rename, sep = ":")
+        }
+        tbl
+      }, tbl = ptb1.list, strata_label = strata_labels, SIMPLIFY = FALSE)
+    }
+    
     if (showAllLevels == T) {
       ptb1.cbind <- Reduce(cbind, c(list(ptb1.list[[1]]), lapply(2:length(ptb1.list), function(x) {
         ptb1.list[[x]][, -1]
@@ -458,17 +472,19 @@ svyCreateTableOneJS <- function(vars, strata = NULL, strata2 = NULL, data, facto
     } else {
       ptb1.cbind <- Reduce(cbind, ptb1.list)
     }
-
+    
     # colnum.test = which(colnames(ptb1.cbind) == "test")
     # ptb1.2group = ptb1.cbind[, c(setdiff(1:ncol(ptb1.cbind), colnum.test), colnum.test[1])]
-    cap.tb1 <- paste("Stratified by ", strata, "(", paste(levels(data[[strata]]), collapse = ", "), ") & ", strata2, "- weighted data", sep = "")
+    cap.tb1 <- paste("Stratified by ", strata, " and ", strata2, "- weighted data", sep = "")
     if (Labels & !is.null(labeldata)) {
+      colname.group_index <- paste(labeldata[variable == strata, var_label][1], ":", labeldata[variable == strata2, var_label][1], sep = "")
+      colnames(ptb1.cbind)[1] <- colname.group_index
       labelled::var_label(data.strata[[1]]$variables) <- sapply(names(data.strata[[1]]$variables), function(v) {
         as.character(labeldata[get("variable") == v, "var_label"][1])
       }, simplify = F)
       # vals.tb1 <- c(NA, unlist(sapply(vars, function(v){labeldata[get("variable") == v, "val_label"]})))
       data.table::setkey(labeldata, variable, level)
-
+      
       res <- tableone::svyCreateTableOne(vars = vars, data = data.strata[[1]], factorVars = factorVars, includeNA = includeNA)
       factor_vars <- res[["MetaData"]][["varFactors"]]
       for (i in seq_along(res$CatTable)) {
@@ -477,23 +493,23 @@ svyCreateTableOneJS <- function(vars, strata = NULL, strata2 = NULL, data, facto
           res$CatTable[[i]][[j]]$level <- labeldata[.(j, lvs), val_label]
         }
       }
-
+      
       ptb1.res <- print(res,
-        showAllLevels = showAllLevels, printToggle = printToggle, quote = quote, varLabels = Labels, nonnormal = nonnormal,
-        catDigits = catDigits, contDigits = contDigits, minMax = minMax
+                        showAllLevels = showAllLevels, printToggle = printToggle, quote = quote, varLabels = Labels, nonnormal = nonnormal,
+                        catDigits = catDigits, contDigits = contDigits, minMax = minMax
       )
       ptb1.rn <- rownames(ptb1.res)
       rownames(ptb1.cbind) <- gsub("(mean (SD))", "", ptb1.rn, fixed = T)
       if (showAllLevels == T) {
         ptb1.cbind[, 1] <- ptb1.res[, 1]
       }
-
-      cap.tb1 <- paste("Stratified by ", labeldata[get("variable") == strata, "var_label"][1], "(", paste(unlist(labeldata[get("variable") == strata, "val_label"]), collapse = ", "), ") & ", labeldata[get("variable") == strata2, "var_label"][1], "- weighted data", sep = "")
+      
+      cap.tb1 <- paste("Stratified by ", labeldata[variable == strata, var_label][1], " and ", labeldata[variable == strata2, var_label][1], "- weighted data", sep = "")
     }
-
+    
     return(list(table = ptb1.cbind, caption = cap.tb1))
   } else {
-
+    
     res2 <- tableone::svyCreateTableOne(vars = vars, strata = c(strata2, strata), data = data, factorVars = factorVars, includeNA = F, test = T, addOverall = addOverall)
     factor_vars <- res2[["MetaData"]][["varFactors"]]
     if (n_original){
@@ -508,9 +524,9 @@ svyCreateTableOneJS <- function(vars, strata = NULL, strata2 = NULL, data, facto
         as.character(labeldata[get("variable") == v, "var_label"][1])
       }, simplify = F)
       data.table::setkey(labeldata, variable, level)
-     
+      
       res0 <- tableone::svyCreateTableOne(vars = vars, data = data, factorVars = factorVars, includeNA = includeNA)
-        
+      
       
       for (i in seq_along(res0$CatTable)) {
         for (j in factor_vars) {
@@ -518,28 +534,28 @@ svyCreateTableOneJS <- function(vars, strata = NULL, strata2 = NULL, data, facto
           res0$CatTable[[i]][[j]]$level <- labeldata[.(j, lvs), val_label]
         }
       }
-
+      
       ptb1.res0 <- print(res0,
-        showAllLevels = showAllLevels, printToggle = printToggle, quote = quote, varLabels = Labels, nonnormal = nonnormal,
-        catDigits = catDigits, contDigits = contDigits, minMax = minMax
+                         showAllLevels = showAllLevels, printToggle = printToggle, quote = quote, varLabels = Labels, nonnormal = nonnormal,
+                         catDigits = catDigits, contDigits = contDigits, minMax = minMax
       )
       ptb1.rn <- rownames(ptb1.res0)
       ptb1.rn <- gsub("(mean (SD))", "", ptb1.rn, fixed = T)
-
+      
       # vals.tb1 <- c(NA, unlist(sapply(vars, function(v){labeldata[get("variable") == v, "val_label"]})))
     }
-
+    
     ptb1 <- print(res,
-      showAllLevels = showAllLevels,
-      printToggle = F, quote = F, smd = smd, varLabels = T, nonnormal = nonnormal,
-      catDigits = catDigits, contDigits = contDigits, pDigits = pDigits, minMax = minMax
+                  showAllLevels = showAllLevels,
+                  printToggle = F, quote = F, smd = smd, varLabels = T, nonnormal = nonnormal,
+                  catDigits = catDigits, contDigits = contDigits, pDigits = pDigits, minMax = minMax
     )
-
+    
     if (showpm) {
       ptb1[grepl("\\(mean \\(SD\\)\\)", rownames(ptb1)), ] <- gsub("\\(", "\u00B1 ", ptb1[grepl("\\(mean \\(SD\\)\\)", rownames(ptb1)), ])
       ptb1[grepl("\\(mean \\(SD\\)\\)", rownames(ptb1)), ] <- gsub("\\)", "", ptb1[grepl("\\(mean \\(SD\\)\\)", rownames(ptb1)), ])
     }
-
+    
     rownames(ptb1) <- gsub("(mean (SD))", "", rownames(ptb1), fixed = T)
     if (Labels & !is.null(labeldata)) {
       rownames(ptb1) <- ptb1.rn
@@ -547,18 +563,18 @@ svyCreateTableOneJS <- function(vars, strata = NULL, strata2 = NULL, data, facto
         ptb1[, 1] <- ptb1.res0[, 1]
       }
     }
-
+    
     sig <- ifelse(ptb1[, "p"] == "<0.001", "0", ptb1[, "p"])
     sig <- as.numeric(as.vector(sig))
     sig <- ifelse(sig <= 0.05, "**", "")
     ptb1 <- cbind(ptb1, sig)
     cap.tb1 <- paste("Stratified by ", strata, " and ", strata2, "- weighted data", sep = "")
-
+    
     if (showpm) {
       ptb1[!grepl("(%)", rownames(ptb1)) & ptb1[, "p"] != "", ] <- gsub("\\(", "\u00B1 ", ptb1[!grepl("(%)", rownames(ptb1)) & ptb1[, "p"] != "", ])
       ptb1[!grepl("(%)", rownames(ptb1)) & ptb1[, "p"] != "", ] <- gsub("\\)", "", ptb1[!grepl("(%)", rownames(ptb1)) & ptb1[, "p"] != "", ])
     }
-
+    
     # Column name
     if (Labels & !is.null(labeldata)) {
       val_combination <- data.table::CJ(labeldata[variable == strata, val_label], labeldata[variable == strata2, val_label], sorted = F)
